==> goods-center-biz-1.6.0-20160902.132233-1-sources.jar: cn/com/duiba/goods/center/biz/service/impl/GoodsTagsServiceImpl.java <==
package cn.com.duiba.goods.center.biz.service.impl;

import cn.com.duiba.dcommons.enums.GoodsTypeEnum;
import cn.com.duiba.goods.center.biz.dao.GoodsTagsDao;
import cn.com.duiba.goods.center.biz.entity.GoodsTagsEntity;
import cn.com.duiba.goods.center.biz.entity.PlatformCouponGoodsEntity;
import cn.com.duiba.goods.center.biz.service.GoodsTagsService;
import cn.com.duiba.wolf.dubbo.DubboResult;
import cn.com.tuia.advert.model.AppTagDto;
import cn.com.tuia.advert.service.RemoteAppTagService;
import com.alibaba.dubbo.common.utils.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service("goodsTagsService")
public class GoodsTagsServiceImpl implements GoodsTagsService {

    private static Logger LOGGER = LoggerFactory.getLogger(GoodsTagsServiceImpl.class);

    @Autowired
    private GoodsTagsDao goodsTagsDao;

    @Autowired
    private RemoteAppTagService remoteAppTagService;

    @Override
    public boolean savePCGTags(Long pcgId, String tags) {
        GoodsTagsEntity goodsTags = goodsTagsDao.selectByGidAndGtype(GoodsTypeEnum.PLATFORM.getGtype(), pcgId);
        if (goodsTags == null) {
            GoodsTagsEntity e4i = new GoodsTagsEntity();
            e4i.setGtype(GoodsTypeEnum.PLATFORM.getGtype());
            e4i.setGid(pcgId);
            e4i.setTags(tags);
            return goodsTagsDao.insert(e4i) > 0;
        }
        return goodsTagsDao.updateTagsById(goodsTags.getId(), tags) > 0;
    }

    @Override
    public GoodsTagsEntity selectByGidAndGtype(Integer gtype, Long gid) {
        return goodsTagsDao.selectByGidAndGtype(gtype,gid);
    }

    @Override
    public List<GoodsTagsEntity> findByPCGIds(List<Long> pcgIds) {
        if (pcgIds == null || pcgIds.isEmpty()) {
            return Collections.emptyList();
        }
        return goodsTagsDao.selectByGtypeAndGids(GoodsTypeEnum.PLATFORM.getGtype(), pcgIds);
    }

    @Override
    public List<Long> getPCGIdsByEntities(List<PlatformCouponGoodsEntity> pcgs) {
        if (pcgs == null) {
            return Collections.emptyList();
        }
        List<Long> pcgIds = new ArrayList<>();
        for (PlatformCouponGoodsEntity it : pcgs) {
            pcgIds.add(it.getPcgId());
        }
        return pcgIds;
    }

    @Override
    public Map<Long, String> getPCGTagsMapByIds(List<Long> pcgIds) {
        if (pcgIds == null || pcgIds.isEmpty()) {
            return Collections.emptyMap();
        }
        List<GoodsTagsEntity> goodsTags = this.findByPCGIds(pcgIds);
        Map<Long, String> pcgTagsMap = new HashMap<>();
        for (GoodsTagsEntity it : goodsTags) {
            pcgTagsMap.put(it.getGid(), it.getTags());
        }
        return pcgTagsMap;
    }

    @Override
    public Map<Long, String> getPCGTagsMapByEntities(List<PlatformCouponGoodsEntity> pcgs) {
        List<Long> pcgIds = getPCGIdsByEntities(pcgs);
        return this.getPCGTagsMapByIds(pcgIds);
    }

    @Override
    public boolean containsAppTag(Long pcgId, Long appId) {
        GoodsTagsEntity goodsTagsEntity = goodsTagsDao.selectByGidAndGtype(GoodsTypeEnum.PLATFORM.getGtype(), pcgId);
        if (goodsTagsEntity == null || StringUtils.isBlank(goodsTagsEntity.getTags())) {
            return false;
        }
        List<String> appTags = this.getAppTags(appId);
        if (appTags == null || appTags.isEmpty()) {
            return false;
        }
        String[] pcgTags = goodsTagsEntity.getTags().split(",");
        List<String> pcgTagList = new ArrayList<>(Arrays.asList(pcgTags));
        pcgTagList.retainAll(appTags);
        return !pcgTagList.isEmpty();
    }

    @Override
    public List<String> getAppTags(Long appId) {
        DubboResult<AppTagDto> result = remoteAppTagService.getAppTagById(appId);
        if (!result.isSuccess()) {
            LOGGER.error("调用 tuia 获取 app 标签异常");
            return Collections.emptyList();
        }
        AppTagDto appTag = result.getResult();
        if (appTag == null) {
            return Collections.emptyList();
        }
        if (appTag.getAppId() == null || StringUtils.isBlank(appTag.getAppTags())) {
            return Collections.emptyList();
        }
        String[] tags = appTag.getAppTags().split(",");
        return new ArrayList<>(Arrays.asList(tags));
    }
}

==> goods-center-biz-1.6.7.6-20161019.054736-1-sources.jar: cn/com/duiba/goods/center/biz/service/impl/GoodsTagsServiceImpl.java <==
package cn.com.duiba.goods.center.biz.service.impl;

import cn.com.duiba.dcommons.enums.GoodsTypeEnum;
import cn.com.duiba.goods.center.biz.dao.GoodsTagsDao;
import cn.com.duiba.goods.center.biz.entity.GoodsTagsEntity;
import cn.com.duiba.goods.center.biz.entity.PlatformCouponGoodsEntity;
import cn.com.duiba.goods.center.biz.service.GoodsTagsService;
import cn.com.duiba.intersection.serivce.api.remoteservice.RemoteAppTagService;
import cn.com.duiba.intersection.serivce.api.remoteservice.dto.AppTagDto;
import cn.com.duiba.wolf.dubbo.DubboResult;
import com.alibaba.dubbo.common.utils.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service("goodsTagsService")
public class GoodsTagsServiceImpl implements GoodsTagsService {

    private static Logger LOGGER = LoggerFactory.getLogger(GoodsTagsServiceImpl.class);

    @Autowired
    private GoodsTagsDao goodsTagsDao;

    @Autowired
    private RemoteAppTagService remoteAppTagService;

    @Override
    public boolean savePCGTags(Long pcgId, String tags) {
        GoodsTagsEntity goodsTags = goodsTagsDao.selectByGidAndGtype(GoodsTypeEnum.PLATFORM.getGtype(), pcgId);
        if (goodsTags == null) {
            GoodsTagsEntity e4i = new GoodsTagsEntity();
            e4i.setGtype(GoodsTypeEnum.PLATFORM.getGtype());
            e4i.setGid(pcgId);
            e4i.setTags(tags);
            return goodsTagsDao.insert(e4i) > 0;
        }
        return goodsTagsDao.updateTagsById(goodsTags.getId(), tags) > 0;
    }

    @Override
    public GoodsTagsEntity selectByGidAndGtype(Integer gtype, Long gid) {
        return goodsTagsDao.selectByGidAndGtype(gtype,gid);
    }

    @Override
    public List<GoodsTagsEntity> findByPCGIds(List<Long> pcgIds) {
        if (pcgIds == null || pcgIds.isEmpty()) {
            return Collections.emptyList();
        }
        return goodsTagsDao.selectByGtypeAndGids(GoodsTypeEnum.PLATFORM.getGtype(), pcgIds);
    }

    @Override
    public List<Long> getPCGIdsByEntities(List<PlatformCouponGoodsEntity> pcgs) {
        if (pcgs == null) {
            return Collections.emptyList();
        }
        List<Long> pcgIds = new ArrayList<>();
        for (PlatformCouponGoodsEntity it : pcgs) {
            pcgIds.add(it.getPcgId());
        }
        return pcgIds;
    }

    @Override
    public Map<Long, String> getPCGTagsMapByIds(List<Long> pcgIds) {
        if (pcgIds == null || pcgIds.isEmpty()) {
            return Collections.emptyMap();
        }
        List<GoodsTagsEntity> goodsTags = this.findByPCGIds(pcgIds);
        Map<Long, String> pcgTagsMap = new HashMap<>();
        for (GoodsTagsEntity it : goodsTags) {
            pcgTagsMap.put(it.getGid(), it.getTags());
        }
        return pcgTagsMap;
    }

    @Override
    public Map<Long, String> getPCGTagsMapByEntities(List<PlatformCouponGoodsEntity> pcgs) {
        List<Long> pcgIds = getPCGIdsByEntities(pcgs);
        return this.getPCGTagsMapByIds(pcgIds);
    }

    @Override
    public boolean containsAppTag(Long pcgId, Long appId) {
        GoodsTagsEntity goodsTagsEntity = goodsTagsDao.selectByGidAndGtype(GoodsTypeEnum.PLATFORM.getGtype(), pcgId);
        if (goodsTagsEntity == null || StringUtils.isBlank(goodsTagsEntity.getTags())) {
            return false;
        }
        List<String> appTags = this.getAppTags(appId);
        if (appTags == null || appTags.isEmpty()) {
            return false;
        }
        String[] pcgTags = goodsTagsEntity.getTags().split(",");
        List<String> pcgTagList = new ArrayList<>(Arrays.asList(pcgTags));
        pcgTagList.retainAll(appTags);
        return !pcgTagList.isEmpty();
    }

    @Override
    public List<String> getAppTags(Long appId) {
        DubboResult<AppTagDto> result = remoteAppTagService.getAppTagById(appId);
        if (!result.isSuccess()) {
            LOGGER.error("调用 tuia 获取 app 标签异常");
            return Collections.emptyList();
        }
        AppTagDto appTag = result.getResult();
        if (appTag == null) {
            return Collections.emptyList();
        }
        if (appTag.getAppId() == null || StringUtils.isBlank(appTag.getAppTags())) {
            return Collections.emptyList();
        }
        String[] tags = appTag.getAppTags().split(",");
        return new ArrayList<>(Arrays.asList(tags));
    }
}
